@@ -656,19 +656,19 @@ class _GenericAdvFuncHelper(FTIndexerMixIn):
         else:
             return 'DROP INDEX %s' % idx
 
-    def sql_create_multicol_unique_index(self, table, columns):
+    def sqls_create_multicol_unique_index(self, table, columns):
         columns = sorted(columns)
         idx = 'unique_%s_%s_idx' % (table, '_'.join(columns))
         sql = 'CREATE UNIQUE INDEX %s ON %s(%s);' % (idx.lower(),
                                                      table,
                                                      ','.join(columns))
-        return sql
+        return [sql]
 
-    def sql_drop_multicol_unique_index(self, table, columns):
+    def sqls_drop_multicol_unique_index(self, table, columns):
         columns = sorted(columns)
         idx = 'unique_%s_%s_idx' % (table, '_'.join(columns))
         sql = 'DROP INDEX %s;' % (idx.lower())
-        return sql
+        return [sql]
 
     def sql_create_sequence(self, seq_name):
         return '''CREATE TABLE %s (last INTEGER);
